#
# spec file for package python-titlecase
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-titlecase
Version:        2.4.1
Release:        1.1
Summary:        Python library to capitalize strings
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/ppannuto/python-titlecase
Source:         https://files.pythonhosted.org/packages/source/t/titlecase/titlecase-%{version}.tar.gz
BuildRequires:  %{python_module regex >= 2020.4.4}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-regex >= 2020.4.4
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This filter changes all words to Title Caps, and attempts to be
clever about SMALL words like a/an/the in the input.

The list of "SMALL words" which are not capped comes from the New
York Times Manual of Style, plus some others like 'vs' and 'v'.

%prep
%setup -q -n titlecase-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/titlecase
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest titlecase/tests.py

%post
%python_install_alternative titlecase

%postun
%python_uninstall_alternative titlecase

%files %{python_files}
%doc README.rst
%python_alternative %{_bindir}/titlecase
%{python_sitelib}/titlecase
%{python_sitelib}/titlecase-%{version}*-info

%changelog
* Tue Oct 24 2023 Dirk Müller <dmueller@suse.com>
- update to 2.4.1:
  * Fix invalid escape sequence warning
* Tue Oct 24 2023 Dirk Müller <dmueller@suse.com>
- add setuptools_scm to get proper versions in the metadata
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.4
  * Add `preserve_blank_lines` option (#88)
  * Add Py3.10, Drop Py3.6
  * Update unit testing framework
* Wed Jan 13 2021 pgajdos@suse.com
- do not nose, but %%pytest
* Fri Jul 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.1.1
  * This adds support for user-customized wordlists
  * This adds a new keyword argument to the `titlecase()` method.
  * This adds environment checks for a wordlist file in the home directory.
  * This drops Py2k support and add 3.8
  * #35: Add fancy double quote to punctuation; Thanks @dwaynebailey!
  * #45: Fix deprecation warning regarding invalid escape sequences. Thanks @tirkarthi
  * #46: Add support for titlecasing non-ASCII letters; Thanks @acabal!
  * #47: Add sphinx documentation to titlecase function; Thanks @1kastner!
  * #49: Remove closing bracket in parser help text; Thanks @1kastner!
  * #53: Add table with examples; Thanks @1kastner!
  * #53: Terms with only consonants should be ALL CAPS; Thanks @Garret-R!
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue May 15 2018 toddrme2178@gmail.com
- Update to 0.12.0
  * Use unicode_literals for Py2 compatibility
  * Handle case of `str` in python 2.
  * More robust against unicode chars
  * Mark strings written by callbacks as immutable
  * Add various dash types
  * cmd: fix check for no additional parameters
  * add small_first_last option
  * allow titlecase to be a command line utility
  * tests for hyphenated McName-Names
  * improve MAC_MC match handling
  * Support for hyphen and em dash delimited sub-phrases.
  * Fix APOS_SECOND possessive noun
  * Add function for customizing small-word list
  * Defer lowering all caps until recursion is done
  * More restrictive regex for 'Mc'
  * Handle `/`'s with recursion so all logic applies
  * Handle single letter + apostrophe better
  * Allow numbers in 'ALL_CAPS' strings
  * Fix MAC/emcee/MacHine casing; add test cases
- Complete rewrite of spec file
- Implement single-spec version
* Wed Jun 29 2011 hvogel@novell.com
- Initial package, version 0.5.1
